@@ -47,6 +47,8 @@ pub struct ProcessMemory {
     handle: usize,
     pid: u32,
     thread: usize,
+    #[cfg(target_os = "macos")]
+    base_size: usize
 }
 
 //
@@ -228,10 +230,11 @@ impl ProcessMemory {
 
         Some(
             ProcessMemory{
-                base_address: base,
+                base_address: base.0,
                 handle: task as _,
                 pid: pid as _,
                 thread: 0,
+                base_size: base.1,
             }
         )
     }
@@ -367,10 +370,11 @@ impl ProcessMemory {
 
         Some(
             ProcessMemory{
-                base_address: base,
+                base_address: base.0,
                 handle: task as _,
                 pid: pid as _,
                 thread: 0,
+                base_size: base.1
             }
         )
     }
@@ -523,6 +527,11 @@ impl ProcessMemory {
     pub fn pid(&self) {
         self.pid;
     }
+
+    #[cfg(target_os = "macos")]
+    pub fn base_size(&self) -> usize {
+        self.base_size
+    }
 }
 
 impl Drop for ProcessMemory {
